@@ -39,6 +39,8 @@ Solvers
 
 .. autofunction:: cho_solve
 .. autofunction:: lu_solve
+.. autofunction:: solve
+.. autofunction:: rsolve
 .. autofunction:: stl
 .. autofunction:: lstsq
 
@@ -51,12 +53,12 @@ from .dot import ddot, dotd
 from .lu import lu_slogdet, lu_solve
 from .property import check_definite_positiveness, check_symmetry
 from .qs import economic_qs, economic_qs_linear
-from .solve import solve
+from .solve import solve, rsolve
 from .svd import economic_svd
 from .tri import stl
 from .lstsq import lstsq
 
 __all__ = ['cho_solve', 'sum2diag', 'trace2', 'ddot', 'dotd', 'lu_slogdet',
            'lu_solve', 'check_definite_positiveness', 'check_symmetry',
-           'economic_qs', 'economic_qs_linear', 'solve', 'economic_svd', 'stl',
-           'lstsq', 'plogdet']
+           'economic_qs', 'economic_qs_linear', 'solve', 'rsolve', 'economic_svd',
+           'stl', 'lstsq', 'plogdet']
